@@ -30,11 +30,11 @@ use crate::client;
 /// ```test_harness,no_run
 /// extern crate hyper;
 /// extern crate hyper_rustls;
-/// extern crate google_pagespeedonline2 as pagespeedonline2;
-/// use pagespeedonline2::{Result, Error};
+/// extern crate google_pagespeedonline4 as pagespeedonline4;
+/// use pagespeedonline4::{Result, Error};
 /// # async fn dox() {
 /// use std::default::Default;
-/// use pagespeedonline2::{Pagespeedonline, oauth2, hyper, hyper_rustls};
+/// use pagespeedonline4::{Pagespeedonline, oauth2, hyper, hyper_rustls};
 /// 
 /// // Get an ApplicationSecret instance by some means. It contains the `client_id` and 
 /// // `client_secret`, among other things.
@@ -48,15 +48,18 @@ use crate::client;
 ///         secret,
 ///         oauth2::InstalledFlowReturnMethod::HTTPRedirect,
 ///     ).build().await.unwrap();
-/// let mut hub = Pagespeedonline::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots().https_or_http().enable_http1().enable_http2().build()), auth);
+/// let mut hub = Pagespeedonline::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()), auth);
 /// // You can configure optional parameters by calling the respective setters at will, and
 /// // execute the final call using `doit()`.
 /// // Values shown here are possibly random and not representative !
 /// let result = hub.pagespeedapi().runpagespeed("url")
-///              .strategy("gubergren")
-///              .screenshot(false)
-///              .add_rule("dolor")
-///              .locale("ea")
+///              .utm_source("ut")
+///              .utm_campaign("gubergren")
+///              .strategy("rebum.")
+///              .snapshots(true)
+///              .screenshot(true)
+///              .add_rule("ipsum")
+///              .locale("est")
 ///              .filter_third_party_resources(true)
 ///              .doit().await;
 /// 
@@ -96,8 +99,8 @@ impl<'a, > Pagespeedonline<> {
         Pagespeedonline {
             client,
             auth: authenticator,
-            _user_agent: "google-api-rust-client/3.1.0".to_string(),
-            _base_url: "https://www.googleapis.com/pagespeedonline/v2/".to_string(),
+            _user_agent: "google-api-rust-client/3.0.0".to_string(),
+            _base_url: "https://www.googleapis.com/pagespeedonline/v4/".to_string(),
             _root_url: "https://www.googleapis.com/".to_string(),
         }
     }
@@ -107,7 +110,7 @@ impl<'a, > Pagespeedonline<> {
     }
 
     /// Set the user-agent header field to use in all requests to the server.
-    /// It defaults to `google-api-rust-client/3.1.0`.
+    /// It defaults to `google-api-rust-client/3.0.0`.
     ///
     /// Returns the previously set user-agent.
     pub fn user_agent(&mut self, agent_name: String) -> String {
@@ -115,7 +118,7 @@ impl<'a, > Pagespeedonline<> {
     }
 
     /// Set the base url to use in all requests to the server.
-    /// It defaults to `https://www.googleapis.com/pagespeedonline/v2/`.
+    /// It defaults to `https://www.googleapis.com/pagespeedonline/v4/`.
     ///
     /// Returns the previously set base url.
     pub fn base_url(&mut self, new_base_url: String) -> String {
@@ -140,14 +143,14 @@ impl<'a, > Pagespeedonline<> {
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct PagespeedApiFormatStringV2 {
+pub struct PagespeedApiFormatStringV4 {
     /// List of arguments for the format string.
-    pub args: Option<Vec<PagespeedApiFormatStringV2Args>>,
+    pub args: Option<Vec<PagespeedApiFormatStringV4Args>>,
     /// A localized format string with {{FOO}} placeholders, where 'FOO' is the key of the argument whose value should be substituted. For HYPERLINK arguments, the format string will instead contain {{BEGIN_FOO}} and {{END_FOO}} for the argument with key 'FOO'.
     pub format: Option<String>,
 }
 
-impl client::Part for PagespeedApiFormatStringV2 {}
+impl client::Part for PagespeedApiFormatStringV4 {}
 
 
 /// There is no detailed description.
@@ -155,7 +158,7 @@ impl client::Part for PagespeedApiFormatStringV2 {}
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct PagespeedApiImageV2 {
+pub struct PagespeedApiImageV4 {
     /// Image data base64 encoded.
     pub data: Option<String>,
     /// Height of screenshot in pixels.
@@ -164,13 +167,13 @@ pub struct PagespeedApiImageV2 {
     pub key: Option<String>,
     /// Mime type of image data (e.g. "image/jpeg").
     pub mime_type: Option<String>,
-    /// The region of the page that is captured by this image, with dimensions measured in CSS pixels.
-    pub page_rect: Option<PagespeedApiImageV2PageRect>,
+    /// no description provided
+    pub page_rect: Option<PagespeedApiImageV4PageRect>,
     /// Width of screenshot in pixels.
     pub width: Option<i32>,
 }
 
-impl client::Part for PagespeedApiImageV2 {}
+impl client::Part for PagespeedApiImageV4 {}
 
 
 /// There is no detailed description.
@@ -183,13 +186,13 @@ impl client::Part for PagespeedApiImageV2 {}
 /// * [runpagespeed pagespeedapi](PagespeedapiRunpagespeedCall) (response)
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct Result {
+pub struct PagespeedApiPagespeedResponseV4 {
     /// The captcha verify result
     #[serde(rename="captchaResult")]
     pub captcha_result: Option<String>,
     /// Localized PageSpeed results. Contains a ruleResults entry for each PageSpeed rule instantiated and run by the server.
     #[serde(rename="formattedResults")]
-    pub formatted_results: Option<ResultFormattedResults>,
+    pub formatted_results: Option<PagespeedApiPagespeedResponseV4FormattedResults>,
     /// Canonicalized and final URL for the document, after following page redirects (if any).
     pub id: Option<String>,
     /// List of rules that were specified in the request, but which the server did not know how to instantiate.
@@ -197,24 +200,29 @@ pub struct Result {
     pub invalid_rules: Option<Vec<String>>,
     /// Kind of result.
     pub kind: Option<String>,
+    /// Metrics of end users' page loading experience.
+    #[serde(rename="loadingExperience")]
+    pub loading_experience: Option<PagespeedApiPagespeedResponseV4LoadingExperience>,
     /// Summary statistics for the page, such as number of JavaScript bytes, number of HTML bytes, etc.
     #[serde(rename="pageStats")]
-    pub page_stats: Option<ResultPageStats>,
+    pub page_stats: Option<PagespeedApiPagespeedResponseV4PageStats>,
     /// Response code for the document. 200 indicates a normal page load. 4xx/5xx indicates an error.
     #[serde(rename="responseCode")]
     pub response_code: Option<i32>,
     /// A map with one entry for each rule group in these results.
     #[serde(rename="ruleGroups")]
-    pub rule_groups: Option<HashMap<String, ResultRuleGroups>>,
+    pub rule_groups: Option<HashMap<String, PagespeedApiPagespeedResponseV4RuleGroups>>,
     /// Base64-encoded screenshot of the page that was analyzed.
-    pub screenshot: Option<PagespeedApiImageV2>,
+    pub screenshot: Option<PagespeedApiImageV4>,
+    /// Additional base64-encoded screenshots of the page, in various partial render states.
+    pub snapshots: Option<Vec<PagespeedApiImageV4>>,
     /// Title of the page, as displayed in the browser's title bar.
     pub title: Option<String>,
     /// The version of PageSpeed used to generate these results.
-    pub version: Option<ResultVersion>,
+    pub version: Option<PagespeedApiPagespeedResponseV4Version>,
 }
 
-impl client::ResponseResult for Result {}
+impl client::ResponseResult for PagespeedApiPagespeedResponseV4 {}
 
 
 /// List of arguments for the format string.
@@ -222,13 +230,13 @@ impl client::ResponseResult for Result {}
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct PagespeedApiFormatStringV2Args {
+pub struct PagespeedApiFormatStringV4Args {
     /// The placeholder key for this arg, as a string.
     pub key: Option<String>,
     /// The screen rectangles being referred to, with dimensions measured in CSS pixels. This is only ever used for SNAPSHOT_RECT arguments. If this is absent for a SNAPSHOT_RECT argument, it means that that argument refers to the entire snapshot.
-    pub rects: Option<Vec<PagespeedApiFormatStringV2ArgsRects>>,
+    pub rects: Option<Vec<PagespeedApiFormatStringV4ArgsRects>>,
     /// Secondary screen rectangles being referred to, with dimensions measured in CSS pixels. This is only ever used for SNAPSHOT_RECT arguments.
-    pub secondary_rects: Option<Vec<PagespeedApiFormatStringV2ArgsSecondaryRects>>,
+    pub secondary_rects: Option<Vec<PagespeedApiFormatStringV4ArgsSecondaryRects>>,
     /// Type of argument. One of URL, STRING_LITERAL, INT_LITERAL, BYTES, DURATION, VERBATIM_STRING, PERCENTAGE, HYPERLINK, or SNAPSHOT_RECT.
     #[serde(rename="type")]
     pub type_: Option<String>,
@@ -236,8 +244,8 @@ pub struct PagespeedApiFormatStringV2Args {
     pub value: Option<String>,
 }
 
-impl client::NestedType for PagespeedApiFormatStringV2Args {}
-impl client::Part for PagespeedApiFormatStringV2Args {}
+impl client::NestedType for PagespeedApiFormatStringV4Args {}
+impl client::Part for PagespeedApiFormatStringV4Args {}
 
 
 /// The screen rectangles being referred to, with dimensions measured in CSS pixels. This is only ever used for SNAPSHOT_RECT arguments. If this is absent for a SNAPSHOT_RECT argument, it means that that argument refers to the entire snapshot.
@@ -245,19 +253,19 @@ impl client::Part for PagespeedApiFormatStringV2Args {}
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct PagespeedApiFormatStringV2ArgsRects {
-    /// The height of the rect.
+pub struct PagespeedApiFormatStringV4ArgsRects {
+    /// no description provided
     pub height: Option<i32>,
-    /// The left coordinate of the rect, in page coordinates.
+    /// no description provided
     pub left: Option<i32>,
-    /// The top coordinate of the rect, in page coordinates.
+    /// no description provided
     pub top: Option<i32>,
-    /// The width of the rect.
+    /// no description provided
     pub width: Option<i32>,
 }
 
-impl client::NestedType for PagespeedApiFormatStringV2ArgsRects {}
-impl client::Part for PagespeedApiFormatStringV2ArgsRects {}
+impl client::NestedType for PagespeedApiFormatStringV4ArgsRects {}
+impl client::Part for PagespeedApiFormatStringV4ArgsRects {}
 
 
 /// Secondary screen rectangles being referred to, with dimensions measured in CSS pixels. This is only ever used for SNAPSHOT_RECT arguments.
@@ -265,39 +273,39 @@ impl client::Part for PagespeedApiFormatStringV2ArgsRects {}
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct PagespeedApiFormatStringV2ArgsSecondaryRects {
-    /// The height of the rect.
+pub struct PagespeedApiFormatStringV4ArgsSecondaryRects {
+    /// no description provided
     pub height: Option<i32>,
-    /// The left coordinate of the rect, in page coordinates.
+    /// no description provided
     pub left: Option<i32>,
-    /// The top coordinate of the rect, in page coordinates.
+    /// no description provided
     pub top: Option<i32>,
-    /// The width of the rect.
+    /// no description provided
     pub width: Option<i32>,
 }
 
-impl client::NestedType for PagespeedApiFormatStringV2ArgsSecondaryRects {}
-impl client::Part for PagespeedApiFormatStringV2ArgsSecondaryRects {}
+impl client::NestedType for PagespeedApiFormatStringV4ArgsSecondaryRects {}
+impl client::Part for PagespeedApiFormatStringV4ArgsSecondaryRects {}
 
 
-/// The region of the page that is captured by this image, with dimensions measured in CSS pixels.
+/// There is no detailed description.
 /// 
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct PagespeedApiImageV2PageRect {
-    /// The height of the rect.
+pub struct PagespeedApiImageV4PageRect {
+    /// no description provided
     pub height: Option<i32>,
-    /// The left coordinate of the rect, in page coordinates.
+    /// no description provided
     pub left: Option<i32>,
-    /// The top coordinate of the rect, in page coordinates.
+    /// no description provided
     pub top: Option<i32>,
-    /// The width of the rect.
+    /// no description provided
     pub width: Option<i32>,
 }
 
-impl client::NestedType for PagespeedApiImageV2PageRect {}
-impl client::Part for PagespeedApiImageV2PageRect {}
+impl client::NestedType for PagespeedApiImageV4PageRect {}
+impl client::Part for PagespeedApiImageV4PageRect {}
 
 
 /// Localized PageSpeed results. Contains a ruleResults entry for each PageSpeed rule instantiated and run by the server.
@@ -305,16 +313,16 @@ impl client::Part for PagespeedApiImageV2PageRect {}
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct ResultFormattedResults {
+pub struct PagespeedApiPagespeedResponseV4FormattedResults {
     /// The locale of the formattedResults, e.g. "en_US".
     pub locale: Option<String>,
     /// Dictionary of formatted rule results, with one entry for each PageSpeed rule instantiated and run by the server.
     #[serde(rename="ruleResults")]
-    pub rule_results: Option<HashMap<String, ResultFormattedResultsRuleResults>>,
+    pub rule_results: Option<HashMap<String, PagespeedApiPagespeedResponseV4FormattedResultsRuleResults>>,
 }
 
-impl client::NestedType for ResultFormattedResults {}
-impl client::Part for ResultFormattedResults {}
+impl client::NestedType for PagespeedApiPagespeedResponseV4FormattedResults {}
+impl client::Part for PagespeedApiPagespeedResponseV4FormattedResults {}
 
 
 /// The enum-like identifier for this rule. For instance "EnableKeepAlive" or "AvoidCssImport". Not localized.
@@ -322,8 +330,10 @@ impl client::Part for ResultFormattedResults {}
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct ResultFormattedResultsRuleResults {
-    /// List of rule groups that this rule belongs to. Each entry in the list is one of "SPEED" or "USABILITY".
+pub struct PagespeedApiPagespeedResponseV4FormattedResultsRuleResults {
+    /// Whether this rule is in 'beta'. Rules in beta are new rules that are being tested, which do not impact the overall score.
+    pub beta: Option<bool>,
+    /// List of rule groups that this rule belongs to. Each entry in the list is one of "SPEED", "USABILITY", or "SECURITY".
     pub groups: Option<Vec<String>>,
     /// Localized name of the rule, intended for presentation to a user.
     #[serde(rename="localizedRuleName")]
@@ -332,14 +342,14 @@ pub struct ResultFormattedResultsRuleResults {
     #[serde(rename="ruleImpact")]
     pub rule_impact: Option<f64>,
     /// A brief summary description for the rule, indicating at a high level what should be done to follow the rule and what benefit can be gained by doing so.
-    pub summary: Option<PagespeedApiFormatStringV2>,
+    pub summary: Option<PagespeedApiFormatStringV4>,
     /// List of blocks of URLs. Each block may contain a heading and a list of URLs. Each URL may optionally include additional details.
     #[serde(rename="urlBlocks")]
-    pub url_blocks: Option<Vec<ResultFormattedResultsRuleResultsUrlBlocks>>,
+    pub url_blocks: Option<Vec<PagespeedApiPagespeedResponseV4FormattedResultsRuleResultsUrlBlocks>>,
 }
 
-impl client::NestedType for ResultFormattedResultsRuleResults {}
-impl client::Part for ResultFormattedResultsRuleResults {}
+impl client::NestedType for PagespeedApiPagespeedResponseV4FormattedResultsRuleResults {}
+impl client::Part for PagespeedApiPagespeedResponseV4FormattedResultsRuleResults {}
 
 
 /// List of blocks of URLs. Each block may contain a heading and a list of URLs. Each URL may optionally include additional details.
@@ -347,15 +357,15 @@ impl client::Part for ResultFormattedResultsRuleResults {}
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct ResultFormattedResultsRuleResultsUrlBlocks {
+pub struct PagespeedApiPagespeedResponseV4FormattedResultsRuleResultsUrlBlocks {
     /// Heading to be displayed with the list of URLs.
-    pub header: Option<PagespeedApiFormatStringV2>,
+    pub header: Option<PagespeedApiFormatStringV4>,
     /// List of entries that provide information about URLs in the url block. Optional.
-    pub urls: Option<Vec<ResultFormattedResultsRuleResultsUrlBlocksUrls>>,
+    pub urls: Option<Vec<PagespeedApiPagespeedResponseV4FormattedResultsRuleResultsUrlBlocksUrls>>,
 }
 
-impl client::NestedType for ResultFormattedResultsRuleResultsUrlBlocks {}
-impl client::Part for ResultFormattedResultsRuleResultsUrlBlocks {}
+impl client::NestedType for PagespeedApiPagespeedResponseV4FormattedResultsRuleResultsUrlBlocks {}
+impl client::Part for PagespeedApiPagespeedResponseV4FormattedResultsRuleResultsUrlBlocks {}
 
 
 /// List of entries that provide information about URLs in the url block. Optional.
@@ -363,15 +373,71 @@ impl client::Part for ResultFormattedResultsRuleResultsUrlBlocks {}
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct ResultFormattedResultsRuleResultsUrlBlocksUrls {
+pub struct PagespeedApiPagespeedResponseV4FormattedResultsRuleResultsUrlBlocksUrls {
     /// List of entries that provide additional details about a single URL. Optional.
-    pub details: Option<Vec<PagespeedApiFormatStringV2>>,
+    pub details: Option<Vec<PagespeedApiFormatStringV4>>,
     /// A format string that gives information about the URL, and a list of arguments for that format string.
-    pub result: Option<PagespeedApiFormatStringV2>,
+    pub result: Option<PagespeedApiFormatStringV4>,
 }
 
-impl client::NestedType for ResultFormattedResultsRuleResultsUrlBlocksUrls {}
-impl client::Part for ResultFormattedResultsRuleResultsUrlBlocksUrls {}
+impl client::NestedType for PagespeedApiPagespeedResponseV4FormattedResultsRuleResultsUrlBlocksUrls {}
+impl client::Part for PagespeedApiPagespeedResponseV4FormattedResultsRuleResultsUrlBlocksUrls {}
+
+
+/// Metrics of end users' page loading experience.
+/// 
+/// This type is not used in any activity, and only used as *part* of another schema.
+/// 
+#[derive(Default, Clone, Debug, Serialize, Deserialize)]
+pub struct PagespeedApiPagespeedResponseV4LoadingExperience {
+    /// The url, pattern or origin which the metrics are on.
+    pub id: Option<String>,
+    /// no description provided
+    pub initial_url: Option<String>,
+    /// no description provided
+    pub metrics: Option<HashMap<String, PagespeedApiPagespeedResponseV4LoadingExperienceMetrics>>,
+    /// no description provided
+    pub overall_category: Option<String>,
+}
+
+impl client::NestedType for PagespeedApiPagespeedResponseV4LoadingExperience {}
+impl client::Part for PagespeedApiPagespeedResponseV4LoadingExperience {}
+
+
+/// The type of the metric.
+/// 
+/// This type is not used in any activity, and only used as *part* of another schema.
+/// 
+#[derive(Default, Clone, Debug, Serialize, Deserialize)]
+pub struct PagespeedApiPagespeedResponseV4LoadingExperienceMetrics {
+    /// no description provided
+    pub category: Option<String>,
+    /// no description provided
+    pub distributions: Option<Vec<PagespeedApiPagespeedResponseV4LoadingExperienceMetricsDistributions>>,
+    /// no description provided
+    pub median: Option<i32>,
+}
+
+impl client::NestedType for PagespeedApiPagespeedResponseV4LoadingExperienceMetrics {}
+impl client::Part for PagespeedApiPagespeedResponseV4LoadingExperienceMetrics {}
+
+
+/// There is no detailed description.
+/// 
+/// This type is not used in any activity, and only used as *part* of another schema.
+/// 
+#[derive(Default, Clone, Debug, Serialize, Deserialize)]
+pub struct PagespeedApiPagespeedResponseV4LoadingExperienceMetricsDistributions {
+    /// no description provided
+    pub max: Option<i32>,
+    /// no description provided
+    pub min: Option<i32>,
+    /// no description provided
+    pub proportion: Option<f64>,
+}
+
+impl client::NestedType for PagespeedApiPagespeedResponseV4LoadingExperienceMetricsDistributions {}
+impl client::Part for PagespeedApiPagespeedResponseV4LoadingExperienceMetricsDistributions {}
 
 
 /// Summary statistics for the page, such as number of JavaScript bytes, number of HTML bytes, etc.
@@ -379,7 +445,9 @@ impl client::Part for ResultFormattedResultsRuleResultsUrlBlocksUrls {}
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct ResultPageStats {
+pub struct PagespeedApiPagespeedResponseV4PageStats {
+    /// Content management system (CMS) used for the page.
+    pub cms: Option<String>,
     /// Number of uncompressed response bytes for CSS resources on the page.
     #[serde(rename="cssResponseBytes")]
     pub css_response_bytes: Option<String>,
@@ -395,6 +463,12 @@ pub struct ResultPageStats {
     /// Number of uncompressed response bytes for JS resources on the page.
     #[serde(rename="javascriptResponseBytes")]
     pub javascript_response_bytes: Option<String>,
+    /// The needed round trips to load render blocking resources
+    #[serde(rename="numRenderBlockingRoundTrips")]
+    pub num_render_blocking_round_trips: Option<i32>,
+    /// The needed round trips to load the full page
+    #[serde(rename="numTotalRoundTrips")]
+    pub num_total_round_trips: Option<i32>,
     /// Number of CSS resources referenced by the page.
     #[serde(rename="numberCssResources")]
     pub number_css_resources: Option<i32>,
@@ -407,36 +481,53 @@ pub struct ResultPageStats {
     /// Number of HTTP resources loaded by the page.
     #[serde(rename="numberResources")]
     pub number_resources: Option<i32>,
+    /// Number of roboted resources.
+    #[serde(rename="numberRobotedResources")]
+    pub number_roboted_resources: Option<i32>,
     /// Number of static (i.e. cacheable) resources on the page.
     #[serde(rename="numberStaticResources")]
     pub number_static_resources: Option<i32>,
+    /// Number of transient-failed resources.
+    #[serde(rename="numberTransientFetchFailureResources")]
+    pub number_transient_fetch_failure_resources: Option<i32>,
     /// Number of response bytes for other resources on the page.
     #[serde(rename="otherResponseBytes")]
     pub other_response_bytes: Option<String>,
+    /// Number of over-the-wire bytes, uses the default gzip compression strategy as an estimation.
+    #[serde(rename="overTheWireResponseBytes")]
+    pub over_the_wire_response_bytes: Option<String>,
+    /// List of roboted urls.
+    #[serde(rename="robotedUrls")]
+    pub roboted_urls: Option<Vec<String>>,
     /// Number of uncompressed response bytes for text resources not covered by other statistics (i.e non-HTML, non-script, non-CSS resources) on the page.
     #[serde(rename="textResponseBytes")]
     pub text_response_bytes: Option<String>,
     /// Total size of all request bytes sent by the page.
     #[serde(rename="totalRequestBytes")]
     pub total_request_bytes: Option<String>,
+    /// List of transient fetch failure urls.
+    #[serde(rename="transientFetchFailureUrls")]
+    pub transient_fetch_failure_urls: Option<Vec<String>>,
 }
 
-impl client::NestedType for ResultPageStats {}
-impl client::Part for ResultPageStats {}
+impl client::NestedType for PagespeedApiPagespeedResponseV4PageStats {}
+impl client::Part for PagespeedApiPagespeedResponseV4PageStats {}
 
 
-/// The name of this rule group: one of "SPEED" or "USABILITY".
+/// The name of this rule group: one of "SPEED", "USABILITY", or "SECURITY".
 /// 
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct ResultRuleGroups {
-    /// The score (0-100) for this rule group, which indicates how much better a page could be in that category (e.g. how much faster, or how much more usable). A high score indicates little room for improvement, while a lower score indicates more room for improvement.
+pub struct PagespeedApiPagespeedResponseV4RuleGroups {
+    /// no description provided
+    pub pass: Option<bool>,
+    /// The score (0-100) for this rule group, which indicates how much better a page could be in that category (e.g. how much faster, or how much more usable, or how much more secure). A high score indicates little room for improvement, while a lower score indicates more room for improvement.
     pub score: Option<i32>,
 }
 
-impl client::NestedType for ResultRuleGroups {}
-impl client::Part for ResultRuleGroups {}
+impl client::NestedType for PagespeedApiPagespeedResponseV4RuleGroups {}
+impl client::Part for PagespeedApiPagespeedResponseV4RuleGroups {}
 
 
 /// The version of PageSpeed used to generate these results.
@@ -444,15 +535,15 @@ impl client::Part for ResultRuleGroups {}
 /// This type is not used in any activity, and only used as *part* of another schema.
 /// 
 #[derive(Default, Clone, Debug, Serialize, Deserialize)]
-pub struct ResultVersion {
+pub struct PagespeedApiPagespeedResponseV4Version {
     /// The major version number of PageSpeed used to generate these results.
     pub major: Option<i32>,
     /// The minor version number of PageSpeed used to generate these results.
     pub minor: Option<i32>,
 }
 
-impl client::NestedType for ResultVersion {}
-impl client::Part for ResultVersion {}
+impl client::NestedType for PagespeedApiPagespeedResponseV4Version {}
+impl client::Part for PagespeedApiPagespeedResponseV4Version {}
 
 
 
@@ -470,18 +561,18 @@ impl client::Part for ResultVersion {}
 /// ```test_harness,no_run
 /// extern crate hyper;
 /// extern crate hyper_rustls;
-/// extern crate google_pagespeedonline2 as pagespeedonline2;
+/// extern crate google_pagespeedonline4 as pagespeedonline4;
 /// 
 /// # async fn dox() {
 /// use std::default::Default;
-/// use pagespeedonline2::{Pagespeedonline, oauth2, hyper, hyper_rustls};
+/// use pagespeedonline4::{Pagespeedonline, oauth2, hyper, hyper_rustls};
 /// 
 /// let secret: oauth2::ApplicationSecret = Default::default();
 /// let auth = oauth2::InstalledFlowAuthenticator::builder(
 ///         secret,
 ///         oauth2::InstalledFlowReturnMethod::HTTPRedirect,
 ///     ).build().await.unwrap();
-/// let mut hub = Pagespeedonline::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots().https_or_http().enable_http1().enable_http2().build()), auth);
+/// let mut hub = Pagespeedonline::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()), auth);
 /// // Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
 /// // like `runpagespeed(...)`
 /// // to build up your call.
@@ -509,7 +600,10 @@ impl<'a> PagespeedapiMethods<'a> {
         PagespeedapiRunpagespeedCall {
             hub: self.hub,
             _url: url.to_string(),
+            _utm_source: Default::default(),
+            _utm_campaign: Default::default(),
             _strategy: Default::default(),
+            _snapshots: Default::default(),
             _screenshot: Default::default(),
             _rule: Default::default(),
             _locale: Default::default(),
@@ -540,25 +634,28 @@ impl<'a> PagespeedapiMethods<'a> {
 /// ```test_harness,no_run
 /// # extern crate hyper;
 /// # extern crate hyper_rustls;
-/// # extern crate google_pagespeedonline2 as pagespeedonline2;
+/// # extern crate google_pagespeedonline4 as pagespeedonline4;
 /// # async fn dox() {
 /// # use std::default::Default;
-/// # use pagespeedonline2::{Pagespeedonline, oauth2, hyper, hyper_rustls};
+/// # use pagespeedonline4::{Pagespeedonline, oauth2, hyper, hyper_rustls};
 /// 
 /// # let secret: oauth2::ApplicationSecret = Default::default();
 /// # let auth = oauth2::InstalledFlowAuthenticator::builder(
 /// #         secret,
 /// #         oauth2::InstalledFlowReturnMethod::HTTPRedirect,
 /// #     ).build().await.unwrap();
-/// # let mut hub = Pagespeedonline::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots().https_or_http().enable_http1().enable_http2().build()), auth);
+/// # let mut hub = Pagespeedonline::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()), auth);
 /// // You can configure optional parameters by calling the respective setters at will, and
 /// // execute the final call using `doit()`.
 /// // Values shown here are possibly random and not representative !
 /// let result = hub.pagespeedapi().runpagespeed("url")
-///              .strategy("amet")
+///              .utm_source("dolor")
+///              .utm_campaign("Lorem")
+///              .strategy("eos")
+///              .snapshots(false)
 ///              .screenshot(true)
-///              .add_rule("sed")
-///              .locale("ut")
+///              .add_rule("duo")
+///              .locale("sed")
 ///              .filter_third_party_resources(true)
 ///              .doit().await;
 /// # }
@@ -568,7 +665,10 @@ pub struct PagespeedapiRunpagespeedCall<'a>
 
     hub: &'a Pagespeedonline<>,
     _url: String,
+    _utm_source: Option<String>,
+    _utm_campaign: Option<String>,
     _strategy: Option<String>,
+    _snapshots: Option<bool>,
     _screenshot: Option<bool>,
     _rule: Vec<String>,
     _locale: Option<String>,
@@ -583,7 +683,7 @@ impl<'a> PagespeedapiRunpagespeedCall<'a> {
 
 
     /// Perform the operation you have build so far.
-    pub async fn doit(mut self) -> client::Result<(hyper::Response<hyper::body::Body>, Result)> {
+    pub async fn doit(mut self) -> client::Result<(hyper::Response<hyper::body::Body>, PagespeedApiPagespeedResponseV4)> {
         use std::io::{Read, Seek};
         use hyper::header::{CONTENT_TYPE, CONTENT_LENGTH, AUTHORIZATION, USER_AGENT, LOCATION};
         use client::ToParts;
@@ -594,11 +694,20 @@ impl<'a> PagespeedapiRunpagespeedCall<'a> {
         };
         dlg.begin(client::MethodInfo { id: "pagespeedonline.pagespeedapi.runpagespeed",
                                http_method: hyper::Method::GET });
-        let mut params: Vec<(&str, String)> = Vec::with_capacity(8 + self._additional_params.len());
+        let mut params: Vec<(&str, String)> = Vec::with_capacity(11 + self._additional_params.len());
         params.push(("url", self._url.to_string()));
+        if let Some(value) = self._utm_source {
+            params.push(("utm_source", value.to_string()));
+        }
+        if let Some(value) = self._utm_campaign {
+            params.push(("utm_campaign", value.to_string()));
+        }
         if let Some(value) = self._strategy {
             params.push(("strategy", value.to_string()));
         }
+        if let Some(value) = self._snapshots {
+            params.push(("snapshots", value.to_string()));
+        }
         if let Some(value) = self._screenshot {
             params.push(("screenshot", value.to_string()));
         }
@@ -613,7 +722,7 @@ impl<'a> PagespeedapiRunpagespeedCall<'a> {
         if let Some(value) = self._filter_third_party_resources {
             params.push(("filter_third_party_resources", value.to_string()));
         }
-        for &field in ["alt", "url", "strategy", "screenshot", "rule", "locale", "filter_third_party_resources"].iter() {
+        for &field in ["alt", "url", "utm_source", "utm_campaign", "strategy", "snapshots", "screenshot", "rule", "locale", "filter_third_party_resources"].iter() {
             if self._additional_params.contains_key(field) {
                 dlg.finished(false);
                 return Err(client::Error::FieldClash(field));
@@ -716,13 +825,34 @@ impl<'a> PagespeedapiRunpagespeedCall<'a> {
         self._url = new_value.to_string();
         self
     }
-    /// The analysis strategy to use
+    /// Campaign source for analytics.
+    ///
+    /// Sets the *utm_source* query property to the given value.
+    pub fn utm_source(mut self, new_value: &str) -> PagespeedapiRunpagespeedCall<'a> {
+        self._utm_source = Some(new_value.to_string());
+        self
+    }
+    /// Campaign name for analytics.
+    ///
+    /// Sets the *utm_campaign* query property to the given value.
+    pub fn utm_campaign(mut self, new_value: &str) -> PagespeedapiRunpagespeedCall<'a> {
+        self._utm_campaign = Some(new_value.to_string());
+        self
+    }
+    /// The analysis strategy (desktop or mobile) to use, and desktop is the default
     ///
     /// Sets the *strategy* query property to the given value.
     pub fn strategy(mut self, new_value: &str) -> PagespeedapiRunpagespeedCall<'a> {
         self._strategy = Some(new_value.to_string());
         self
     }
+    /// Indicates if binary data containing snapshot images should be included
+    ///
+    /// Sets the *snapshots* query property to the given value.
+    pub fn snapshots(mut self, new_value: bool) -> PagespeedapiRunpagespeedCall<'a> {
+        self._snapshots = Some(new_value);
+        self
+    }
     /// Indicates if binary data containing a screenshot should be included
     ///
     /// Sets the *screenshot* query property to the given value.
